@@ -28,7 +28,6 @@
 
 #include "khmthemefactory.h"
 
-class KEduVocDocument;
 class QQmlEngine;
 class QQuickWidget;
 class KHelpMenu;
@@ -121,8 +120,6 @@ public:
 
     Q_INVOKABLE QStringList alphabet() const;
 
-    Q_INVOKABLE QStringList languageNames() const;
-
     /** Return true if the word contains the char in the QString */
     Q_INVOKABLE bool containsChar(const QString &original);
 
@@ -193,10 +190,8 @@ private:
      */
     QString stripAccents(const QString & original);
 
-    ///Set the level and make sure it exists
-    void setLevel();
-    ///Scan the files in the selected language dir to set the levels, returns true if succeeds
-    bool loadLevels();
+    ///Scan the files in the selected language dir to set the levels
+    void loadLevels();
     // Populate m_specialCharacters if the
     // current language has special characters.
     void loadLanguageSpecialCharacters();
@@ -245,9 +240,6 @@ private:
     //The random sequence of words of the current level file
     QList<QPair<QString, QString> > m_randomList;
 
-    //Current level file
-    KEduVocDocument *m_doc;
-
     /** The word to be guessed */
     QString m_originalWord;
 
